@@ -57,7 +57,7 @@ class TorchSkeleton:
         offsets = []
         for joint in kinematic_chain:
             offsets.append(kinematic_chain[joint]['offsets'].squeeze())
-        self._offset_arr = torch.Tensor(offsets, device=self.device)
+        self._offset_arr = torch.FloatTensor(offsets, device=self.device)
         return kinematic_chain
 
     def forward_kinematics(self, root_positions: torch.Tensor, rotations: torch.Tensor, rot_repr='quaternion'):
